gen.evidence: Generate a sequence of evidence for a continuous node in a conditional gaussian bayesian network.
Description
The evidence for a node in an RHugin domain is generated as a linear sequence within the specified standard deviation from the marginal mean of the node. The evidence can be given as an input to absorb.gnbp
an object of class "gpfit" obtained by using fit.gnbp
node
a character string specifying the name of a continuous node in the domain
std
a numeric value specifying the number of standard deviations of marginal distribution within which the evidence is generated. A numeric vector of length = number of nodes, must be specified when std.equal=FALSE.
length.out
a positive integer giving the desired length of the sequence.
std.equal
a logical value indicating whether same number of standard deviations should be used to generate evidence for all nodes. Default is TRUE.
Value
A matrix of evidence for each specified node
Details
The evidence for a node in an RHugin domain is generated as a linear sequence within the specified standard deviation from the marginal mean of the node. The evidence can be given as an input to absorb.gnbp
##Fit a networkdata(mouse)
network<-fit.gnbp(mousegeno,mousepheno,alpha=0.1)
##Generate a sequence of evidence for a single nodeevidence<-gen.evidence(network,node="Tlr12",std=2,length.out=20)