fit.gnbp(geno,pheno,constraints,learn="TRUE",edgelist,type ="cg",
alpha=0.001,tol=1e-04,maxit=0)type = "cg" or class factor if type = "db" and non-empty column names."cg" for Conditional Gaussian (default) and "db" for Discrete Bayesian.learn.cpt for details.learn.cpt for details.Conditional Gaussian or Discrete Bayesian)learn.structure. Briefly, the constraints argument is a list of two elements: directed and undirected. Each of these elements in turn should be a list with two elements: required and forbidden. The elements of required and forbidden must be a character vector of length two specifying the names of the nodes. See learn.cpt for details.absorb.gnbpdata(mouse)
## Simple example : Fit a bayesian network to genotype-phenotype data using the default values
fit.gnbp(mousegeno,mousepheno)
## Fit a bayesian network to genotype-phenotype data at a specified significance level
fit.gnbp(mousegeno,mousepheno,alpha = 0.1)Run the code above in your browser using DataLab